# eric7.WebBrowser.GreaseMonkey.GreaseMonkeyConfiguration.GreaseMonkeyConfigurationListWidget

Module implementing a special list widget for GreaseMonkey scripts.

### Global Attributes

None

### Classes

GreaseMonkeyConfigurationListWidget | Class implementing a special list widget for GreaseMonkey scripts.

### Functions

None

## GreaseMonkeyConfigurationListWidget

Class implementing a special list widget for GreaseMonkey scripts.

### Signals

removeItemRequested(item)
  emitted to indicate an item removal request (QListWidgetItem)

### Derived from

QListWidget

### Class Attributes

None

### Class Methods

None

### Methods

GreaseMonkeyConfigurationListWidget | Constructor
__containsRemoveIcon | Private method to check, if the given position is inside the remove icon.
mouseDoubleClickEvent | Protected method handling mouse double click events.
mousePressEvent | Protected method handling presses of mouse buttons.

### Static Methods

None

#### GreaseMonkeyConfigurationListWidget (Constructor)

GreaseMonkeyConfigurationListWidget(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### GreaseMonkeyConfigurationListWidget.__containsRemoveIcon

__containsRemoveIcon(pos)

Private method to check, if the given position is inside the remove icon.

pos (QPoint)
  position to check for

Return:
  flag indicating success

Return Type:
  bool

#### GreaseMonkeyConfigurationListWidget.mouseDoubleClickEvent

mouseDoubleClickEvent(evt)

Protected method handling mouse double click events.

evt (QMouseEvent)
  mouse press event

#### GreaseMonkeyConfigurationListWidget.mousePressEvent

mousePressEvent(evt)

Protected method handling presses of mouse buttons.

evt (QMouseEvent)
  mouse press event

Up